@@ -18,6 +18,8 @@ import ckan.model as model
 import ckan.plugins as p
 import ckan.lib.helpers as h
 import ckan.lib.app_globals as app_globals
+import ckan.logic as logic
+
 
 log = logging.getLogger(__name__)
 
@@ -347,3 +349,10 @@ def load_environment(global_conf, app_conf):
 
     for plugin in p.PluginImplementations(p.IConfigurable):
         plugin.configure(config)
+
+    # Here we create the site user if they are not already in the database
+    try:
+        logic.get_action('get_site_user')({'ignore_auth': True}, None)
+    except sqlalchemy.exc.ProgrammingError:
+        # The database is not initialised.  This is a bit dirty.
+        pass
