@@ -5,13 +5,65 @@ may take precedent over the more generic routes. For more information
 refer to the routes manual at http://routes.groovie.org/docs/
 
 """
+import re
+
 from pylons import config
-from routes import Mapper
+from routes.mapper import SubMapper, Mapper as _Mapper
+
 from ckan.plugins import PluginImplementations, IRoutes
 
+named_routes = {}
 
 routing_plugins = PluginImplementations(IRoutes)
 
+
+class Mapper(_Mapper):
+    ''' This Mapper allows us to intercept the connect calls used by routes
+    so that we can collect named routes and later use them to create links
+    via some helper functions like build_nav(). '''
+
+    def connect(self, *args, **kw):
+        '''Connect a new route, storing any named routes for later.
+
+        This custom connect() method wraps the standard connect() method,
+        and additionally saves any named routes that are connected in a dict
+        ckan.routing.named_routes, which ends up being accessible via the
+        Pylons config as config['routes.named_routes'].
+
+        Also takes some additional params:
+
+        :param ckan_icon: name of the icon to be associated with this route,
+            e.g. 'group', 'time'
+        :type ckan_icon: string
+        :param highlight_actions: space-separated list of controller actions
+            that should be treated as the same as this named route for menu
+            highlighting purposes, e.g. 'index search'
+        :type highlight_actions: string
+
+        '''
+        ckan_icon = kw.pop('ckan_icon', None)
+        highlight_actions = kw.pop('highlight_actions', kw.get('action', ''))
+        out = _Mapper.connect(self, *args, **kw)
+        if len(args) == 1 or args[0].startswith('_redirect_'):
+            return out
+        # we have a named route
+        needed = []
+        matches = re.findall('\{([^:}]*)(\}|:)', args[1])
+        for match in matches:
+            needed.append(match[0])
+        route_data = {
+            'icon': ckan_icon,
+            # needed lists the names of the parameters that need defining
+            # for the route to be generated
+            'needed': needed,
+            'controller': kw.get('controller'),
+            'action': kw.get('action', ''),
+            'highlight_actions': highlight_actions
+        }
+        named_routes[args[0]] = route_data
+        return out
+
+
 def make_map():
     """Create, configure and return the routes Mapper"""
     # import controllers here rather than at root level because
@@ -58,7 +110,6 @@ def make_map():
             'tag',
             'group',
             'related',
-            'authorizationgroup',
             'revision',
             'licenses',
             'rating',
@@ -119,8 +170,6 @@ def make_map():
                   action='format_autocomplete', conditions=GET)
         m.connect('/util/resource/format_icon',
                   action='format_icon', conditions=GET)
-        m.connect('/util/authorizationgroup/autocomplete',
-                  action='authorizationgroup_autocomplete')
         m.connect('/util/group/autocomplete', action='group_autocomplete')
         m.connect('/util/markdown', action='markdown')
         m.connect('/util/dataset/munge_name', action='munge_package_name')
@@ -128,46 +177,36 @@ def make_map():
                   action='munge_title_to_package_name')
         m.connect('/util/tag/munge', action='munge_tag')
         m.connect('/util/status', action='status')
+        m.connect('/util/snippet/{snippet_path:.*}', action='snippet')
+        m.connect('/i18n/{lang}', action='i18n_js_translations')
 
     ###########
     ## /END API
     ###########
 
-
-    ## Webstore
-    if config.get('ckan.datastore.enabled', False):
-        with SubMapper(map, controller='datastore') as m:
-            m.connect('datastore_read', '/api/data/{id}{url:(/.*)?}',
-                      action='read', url='', conditions=GET)
-            m.connect('datastore_write', '/api/data/{id}{url:(/.*)?}',
-                      action='write', url='', conditions=PUT_POST_DELETE)
-            m.connect('datastore_read_shortcut',
-                      '/dataset/{dataset}/resource/{id}/api{url:(/.*)?}',
-                      action='read', url='', conditions=GET)
-            m.connect('datastore_write_shortcut',
-                      '/dataset/{dataset}/resource/{id}/api{url:(/.*)?}',
-                      action='write', url='', conditions=PUT_POST_DELETE)
-
     map.redirect('/packages', '/dataset')
     map.redirect('/packages/{url:.*}', '/dataset/{url}')
     map.redirect('/package', '/dataset')
     map.redirect('/package/{url:.*}', '/dataset/{url}')
 
-    ##to get back formalchemy uncomment these lines
-    ##map.connect('/package/new', controller='package_formalchemy', action='new')
-    ##map.connect('/package/edit/{id}', controller='package_formalchemy', action='edit')
-
     with SubMapper(map, controller='related') as m:
-        m.connect('related_list', '/dataset/{id}/related', action='list')
-        m.connect('related_read', '/apps/{id}', action='read')
-        m.connect('related_dashboard', '/apps', action='dashboard')
+        m.connect('related_new',  '/dataset/{id}/related/new', action='new')
+        m.connect('related_edit', '/dataset/{id}/related/edit/{related_id}',
+                  action='edit')
+        m.connect('related_delete', '/dataset/{id}/related/delete/{related_id}',
+                  action='delete')
+        m.connect('related_list', '/dataset/{id}/related', action='list',
+                  ckan_icon='picture')
+        m.connect('related_read', '/related/{id}', action='read')
+        m.connect('related_dashboard', '/related', action='dashboard')
 
     with SubMapper(map, controller='package') as m:
-        m.connect('/dataset', action='search')
+        m.connect('search', '/dataset', action='search',
+                  highlight_actions='index search')
+        m.connect('add dataset', '/dataset/new', action='new')
         m.connect('/dataset/{action}',
           requirements=dict(action='|'.join([
               'list',
-              'new',
               'autocomplete',
               'search'
               ]))
@@ -177,31 +216,46 @@ def make_map():
           requirements=dict(action='|'.join([
           'read',
           'edit',
-          'authz',
           'history',
           ]))
         )
         m.connect('/dataset/{action}/{id}',
           requirements=dict(action='|'.join([
           'edit',
-          'editresources',
-          'authz',
+          'new_metadata',
+          'new_resource',
           'history',
           'read_ajax',
           'history_ajax',
-          'followers',
+          'follow',
+          'activity',
+          'unfollow',
+          'delete',
+          'api_data',
           ]))
           )
+        m.connect('dataset_followers', '/dataset/followers/{id}',
+                  action='followers', ckan_icon='group')
+        m.connect('dataset_activity', '/dataset/activity/{id}',
+                  action='activity', ckan_icon='time')
+        m.connect('/dataset/activity/{id}/{offset}', action='activity')
         m.connect('/dataset/{id}.{format}', action='read')
-        m.connect('/dataset/{id}', action='read')
+        m.connect('dataset_read', '/dataset/{id}', action='read',
+                  ckan_icon='sitemap')
         m.connect('/dataset/{id}/resource/{resource_id}',
                   action='resource_read')
+        m.connect('/dataset/{id}/resource_delete/{resource_id}',
+                  action='resource_delete')
+        m.connect('/dataset/{id}/resource_edit/{resource_id}',
+                  action='resource_edit')
         m.connect('/dataset/{id}/resource/{resource_id}/download',
                   action='resource_download')
         m.connect('/dataset/{id}/resource/{resource_id}/embed',
                   action='resource_embedded_dataviewer')
         m.connect('/dataset/{id}/resource/{resource_id}/viewer',
                   action='resource_embedded_dataviewer', width="960", height="800")
+        m.connect('/dataset/{id}/resource/{resource_id}/preview',
+                  action='resource_datapreview')
 
     # group
     map.redirect('/groups', '/group')
@@ -214,32 +268,59 @@ def make_map():
     # These named routes are used for custom group forms which will use the
     # names below based on the group.type ('group' is the default type)
     with SubMapper(map, controller='group') as m:
-        m.connect('group_index', '/group', action='index')
+        m.connect('group_index', '/group', action='index',
+                  highlight_actions='index search')
         m.connect('group_list', '/group/list', action='list')
         m.connect('group_new',  '/group/new', action='new')
         m.connect('group_action', '/group/{action}/{id}',
           requirements=dict(action='|'.join([
           'edit',
-          'authz',
-          'history'
+          'delete',
+          'members',
+          'member_new',
+          'member_delete',
+          'history',
+          'followers',
+          'follow',
+          'unfollow',
+          'admins',
+          'activity',
           ]))
           )
-        m.connect('group_read', '/group/{id}', action='read')
+        m.connect('group_about', '/group/about/{id}', action='about',
+                  ckan_icon='info-sign'),
+        m.connect('group_activity', '/group/activity/{id}/{offset}',
+                  action='activity', ckan_icon='time'),
+        m.connect('group_read', '/group/{id}', action='read',
+                  ckan_icon='sitemap')
 
+    # organizations these basically end up being the same as groups
+    with SubMapper(map, controller='organization') as m:
+        m.connect('organizations_index', '/organization', action='index')
+        m.connect('/organization/list', action='list')
+        m.connect('/organization/new', action='new')
+        m.connect('/organization/{action}/{id}',
+          requirements=dict(action='|'.join([
+          'edit',
+          'delete',
+          'admins',
+          'members',
+          'member_new',
+          'member_delete',
+          'history',
+          'bulk_process',
+          'about',
+          ]))
+          )
+        m.connect('organization_activity', '/organization/activity/{id}',
+                  action='activity', ckan_icon='time')
+        m.connect('organization_about', '/organization/about/{id}',
+                  action='about', ckan_icon='info-sign')
+        m.connect('organization_read', '/organization/{id}', action='read',
+                  ckan_icon='sitemap')
     register_package_plugins(map)
     register_group_plugins(map)
 
-    # authz group
-    map.redirect('/authorizationgroups', '/authorizationgroup')
-    map.redirect('/authorizationgroups/{url:.*}', '/authorizationgroup/{url}')
-    with SubMapper(map, controller='authorization_group') as m:
-        m.connect('/authorizationgroup', action='index')
-        m.connect('/authorizationgroup/list', action='list')
-        m.connect('/authorizationgroup/new', action='new')
-        m.connect('/authorizationgroup/edit/{id}', action='edit')
-        m.connect('/authorizationgroup/authz/{id}', action='authz')
-        m.connect('/authorizationgroup/{id}', action='read')
-
     # tags
     map.redirect('/tags', '/tag')
     map.redirect('/tags/{url:.*}', '/tag/{url}')
@@ -253,12 +334,21 @@ def make_map():
         m.connect('/user/edit', action='edit')
         # Note: openid users have slashes in their ids, so need the wildcard
         # in the route.
-        m.connect('/user/dashboard', action='dashboard')
-        m.connect('/user/followers/{id:.*}', action='followers')
-        m.connect('/user/edit/{id:.*}', action='edit')
+        m.connect('/user/activity/{id}/{offset}', action='activity')
+        m.connect('user_activity_stream', '/user/activity/{id}',
+                  action='activity', ckan_icon='time')
+        m.connect('/dashboard/{offset}', action='dashboard')
+        m.connect('user_dashboard', '/dashboard', action='dashboard',
+                  ckan_icon='list')
+        m.connect('user_follow', '/user/follow/{id}', action='follow')
+        m.connect('/user/unfollow/{id}', action='unfollow')
+        m.connect('user_followers', '/user/followers/{id:.*}',
+                  action='followers', ckan_icon='group')
+        m.connect('user_edit', '/user/edit/{id:.*}', action='edit',
+                  ckan_icon='cog')
         m.connect('/user/reset/{id:.*}', action='perform_reset')
-        m.connect('/user/register', action='register')
-        m.connect('/user/login', action='login')
+        m.connect('register', '/user/register', action='register')
+        m.connect('login', '/user/login', action='login')
         m.connect('/user/_logout', action='logout')
         m.connect('/user/logged_in', action='logged_in')
         m.connect('/user/logged_out', action='logged_out')
@@ -266,8 +356,9 @@ def make_map():
         m.connect('/user/reset', action='request_reset')
         m.connect('/user/me', action='me')
         m.connect('/user/set_lang/{lang}', action='set_lang')
-        m.connect('/user/{id:.*}', action='read')
-        m.connect('/user', action='index')
+        m.connect('user_datasets', '/user/{id:.*}', action='read',
+                  ckan_icon='sitemap')
+        m.connect('user_index', '/user', action='index')
 
     with SubMapper(map, controller='revision') as m:
         m.connect('/revision', action='index')
@@ -283,7 +374,10 @@ def make_map():
         m.connect('/feeds/dataset.atom', action='general')
         m.connect('/feeds/custom.atom', action='custom')
 
-    map.connect('ckanadmin_index', '/ckan-admin', controller='admin', action='index')
+    map.connect('ckanadmin_index', '/ckan-admin', controller='admin',
+                action='index', ckan_icon='legal')
+    map.connect('ckanadmin_config', '/ckan-admin/config', controller='admin',
+                action='config', ckan_icon='check')
     map.connect('ckanadmin', '/ckan-admin/{action}', controller='admin')
 
     # Storage routes
@@ -312,46 +406,21 @@ def make_map():
         m.connect('storage_file', '/storage/f/{label:.*}',
                   action='file')
 
+    with SubMapper(map, controller='util') as m:
+        m.connect('/i18n/strings_{lang}.js', action='i18n_js_strings')
+        m.connect('/util/redirect', action='redirect')
+        m.connect('/testing/primer', action='primer')
+        m.connect('/testing/markup', action='markup')
 
     for plugin in routing_plugins:
         map = plugin.after_map(map)
 
+    # sometimes we get requests for favicon.ico we should redirect to
+    # the real favicon location.
+    map.redirect('/favicon.ico', config.get('ckan.favicon'))
 
     map.redirect('/*(url)/', '/{url}',
                  _redirect_code='301 Moved Permanently')
     map.connect('/*url', controller='template', action='view')
 
     return map
-
-class SubMapper(object):
-    # FIXME this is only used due to a bug in routes 1.11
-    # hopefully we can use map.submapper(...) in version 1.12
-    """Partial mapper for use with_options"""
-    def __init__(self, obj, **kwargs):
-        self.kwargs = kwargs
-        self.obj = obj
-
-    def connect(self, *args, **kwargs):
-        newkargs = {}
-        newargs = args
-        for key in self.kwargs:
-            if key == 'path_prefix':
-                if len(args) > 1:
-                    newargs = (args[0], self.kwargs[key] + args[1])
-                else:
-                    newargs = (self.kwargs[key] + args[0],)
-            elif key in kwargs:
-                newkargs[key] = self.kwargs[key] + kwargs[key]
-            else:
-                newkargs[key] = self.kwargs[key]
-        for key in kwargs:
-            if key not in self.kwargs:
-                newkargs[key] = kwargs[key]
-        return self.obj.connect(*newargs, **newkargs)
-
-    # Provided for those who prefer using the 'with' syntax in Python 2.5+
-    def __enter__(self):
-        return self
-
-    def __exit__(self, type, value, tb):
-        pass
