@@ -1,19 +1,19 @@
-import sys
 from datetime import datetime, timedelta
 
-from pylons.i18n import get_lang
+from pylons.i18n import get_lang, _
+from pylons import c, request
 
 from ckan.logic import NotAuthorized, check_access
 
-from ckan.lib.base import *
-from ckan.lib.helpers import Page
-import ckan.authz
+import ckan.lib.base as base
+import ckan.model as model
+import ckan.lib.helpers as h
 
 
-class RevisionController(BaseController):
+class RevisionController(base.BaseController):
 
     def __before__(self, action, **env):
-        BaseController.__before__(self, action, **env)
+        base.BaseController.__before__(self, action, **env)
 
         context = {'model': model, 'user': c.user or c.author}
         if c.user:
@@ -27,7 +27,7 @@ class RevisionController(BaseController):
         try:
             check_access('site_read', context)
         except NotAuthorized:
-            abort(401, _('Not authorized to see this page'))
+            base.abort(401, _('Not authorized to see this page'))
 
     def index(self):
         return self.list()
@@ -70,6 +70,8 @@ class RevisionController(BaseController):
                         # but in the meantime while that is fixed,
                         # avoid an exception here
                         continue
+                    if package.private:
+                        continue
                     number = len(package.all_revisions)
                     package_revision = None
                     count = 0
@@ -126,35 +128,36 @@ class RevisionController(BaseController):
             return feed.writeString('utf-8')
         else:
             query = model.Session.query(model.Revision)
-            c.page = Page(
+            c.page = h.Page(
                 collection=query,
                 page=request.params.get('page', 1),
                 url=h.pager_url,
                 items_per_page=20
             )
-            return render('revision/list.html')
+            return base.render('revision/list.html')
 
     def read(self, id=None):
         if id is None:
-            abort(404)
+            base.abort(404)
         c.revision = model.Session.query(model.Revision).get(id)
         if c.revision is None:
-            abort(404)
+            base.abort(404)
 
         pkgs = model.Session.query(model.PackageRevision).\
             filter_by(revision=c.revision)
-        c.packages = [pkg.continuity for pkg in pkgs]
+        c.packages = [pkg.continuity for pkg in pkgs if not pkg.private]
         pkgtags = model.Session.query(model.PackageTagRevision).\
             filter_by(revision=c.revision)
-        c.pkgtags = [pkgtag.continuity for pkgtag in pkgtags]
+        c.pkgtags = [pkgtag.continuity for pkgtag in pkgtags
+                     if not pkgtag.package.private]
         grps = model.Session.query(model.GroupRevision).\
             filter_by(revision=c.revision)
         c.groups = [grp.continuity for grp in grps]
-        return render('revision/read.html')
+        return base.render('revision/read.html')
 
     def diff(self, id=None):
         if 'diff' not in request.params or 'oldid' not in request.params:
-            abort(400)
+            base.abort(400)
         c.revision_from = model.Session.query(model.Revision).get(
             request.params.getone('oldid'))
         c.revision_to = model.Session.query(model.Revision).get(
@@ -168,23 +171,23 @@ class RevisionController(BaseController):
             c.group = model.Group.by_name(id)
             diff = c.group.diff(c.revision_to, c.revision_from)
         else:
-            abort(400)
+            base.abort(400)
 
         c.diff = diff.items()
         c.diff.sort()
-        return render('revision/diff.html')
+        return base.render('revision/diff.html')
 
     def edit(self, id=None):
         if id is None:
-            abort(404)
+            base.abort(404)
         revision = model.Session.query(model.Revision).get(id)
         if revision is None:
-            abort(404)
+            base.abort(404)
         action = request.params.get('action', '')
         if action in ['delete', 'undelete']:
             # this should be at a lower level (e.g. logic layer)
             if not c.revision_change_state_allowed:
-                abort(401)
+                base.abort(401)
             if action == 'delete':
                 revision.state = model.State.DELETED
             elif action == 'undelete':
