@@ -1,28 +1,41 @@
 import logging
-from pylons import session
-
-import genshi
 from urllib import quote
 
-import ckan.misc
-import ckan.lib.i18n
-from ckan.lib.base import *
-from ckan.lib import mailer
-from ckan.authz import Authorizer
-from ckan.lib.navl.dictization_functions import DataError, unflatten
-from ckan.logic import NotFound, NotAuthorized, ValidationError
-from ckan.logic import check_access, get_action
-from ckan.logic import tuplize_dict, clean_dict, parse_params
-from ckan.logic.schema import user_new_form_schema, user_edit_form_schema
-from ckan.lib.captcha import check_recaptcha, CaptchaError
+from pylons import session, c, g, request, config
+from pylons.i18n import _
+
+import ckan.lib.i18n as i18n
+import ckan.lib.base as base
+import ckan.model as model
+import ckan.lib.helpers as h
+import ckan.new_authz as new_authz
+import ckan.logic as logic
+import ckan.logic.schema as schema
+import ckan.lib.captcha as captcha
+import ckan.lib.mailer as mailer
+import ckan.lib.navl.dictization_functions as dictization_functions
 
 log = logging.getLogger(__name__)
 
 
-class UserController(BaseController):
+abort = base.abort
+render = base.render
+validate = base.validate
+
+check_access = logic.check_access
+get_action = logic.get_action
+NotFound = logic.NotFound
+NotAuthorized = logic.NotAuthorized
+ValidationError = logic.ValidationError
+
+DataError = dictization_functions.DataError
+unflatten = dictization_functions.unflatten
+
+
+class UserController(base.BaseController):
 
     def __before__(self, action, **env):
-        BaseController.__before__(self, action, **env)
+        base.BaseController.__before__(self, action, **env)
         try:
             context = {'model': model, 'user': c.user or c.author}
             check_access('site_read', context)
@@ -35,21 +48,21 @@ class UserController(BaseController):
     edit_user_form = 'user/edit_user_form.html'
 
     def _new_form_to_db_schema(self):
-        return user_new_form_schema()
+        return schema.user_new_form_schema()
 
     def _db_to_new_form_schema(self):
         '''This is an interface to manipulate data from the database
         into a format suitable for the form (optional)'''
 
     def _edit_form_to_db_schema(self):
-        return user_edit_form_schema()
+        return schema.user_edit_form_schema()
 
     def _db_to_edit_form_schema(self):
         '''This is an interface to manipulate data from the database
         into a format suitable for the form (optional)'''
 
     def _setup_template_variables(self, context, data_dict):
-        c.is_sysadmin = Authorizer().is_sysadmin(c.user)
+        c.is_sysadmin = new_authz.is_sysadmin(c.user)
         try:
             user_dict = get_action('user_show')(context, data_dict)
         except NotFound:
@@ -58,6 +71,7 @@ class UserController(BaseController):
             abort(401, _('Not authorized to see this page'))
         c.user_dict = user_dict
         c.is_myself = user_dict['name'] == c.user
+        c.about_formatted = h.render_markdown(user_dict['about'])
 
     ## end hooks
 
@@ -74,9 +88,7 @@ class UserController(BaseController):
         c.q = request.params.get('q', '')
         c.order_by = request.params.get('order_by', 'name')
 
-        context = {'model': model,
-                   'user': c.user or c.author,
-                   'return_query': True}
+        context = {'return_query': True}
 
         data_dict = {'q': c.q,
                      'order_by': c.order_by}
@@ -110,15 +122,18 @@ class UserController(BaseController):
 
         self._setup_template_variables(context, data_dict)
 
-        c.about_formatted = self._format_about(c.user_dict['about'])
-        c.user_activity_stream = get_action('user_activity_list_html')(
-            context, {'id': c.user_dict['id']})
+        # The legacy templates have the user's activity stream on the user
+        # profile page, new templates do not.
+        if h.asbool(config.get('ckan.legacy_templates', False)):
+            c.user_activity_stream = get_action('user_activity_list_html')(
+                context, {'id': c.user_dict['id']})
+
         return render('user/read.html')
 
     def me(self, locale=None):
         if not c.user:
-            h.redirect_to(locale=locale, controller='user',
-                          action='login', id=None)
+            h.redirect_to(locale=locale, controller='user', action='login',
+                          id=None)
         user_ref = c.userobj.get_reference_preferred_for_uri()
         h.redirect_to(locale=locale, controller='user', action='dashboard',
                       id=user_ref)
@@ -152,16 +167,16 @@ class UserController(BaseController):
         error_summary = error_summary or {}
         vars = {'data': data, 'errors': errors, 'error_summary': error_summary}
 
-        c.is_sysadmin = Authorizer().is_sysadmin(c.user)
+        c.is_sysadmin = new_authz.is_sysadmin(c.user)
         c.form = render(self.new_user_form, extra_vars=vars)
         return render('user/new.html')
 
     def _save_new(self, context):
         try:
-            data_dict = clean_dict(unflatten(
-                tuplize_dict(parse_params(request.params))))
+            data_dict = logic.clean_dict(unflatten(
+                logic.tuplize_dict(logic.parse_params(request.params))))
             context['message'] = data_dict.get('log_message', '')
-            check_recaptcha(request)
+            captcha.check_recaptcha(request)
             user = get_action('user_create')(context, data_dict)
         except NotAuthorized:
             abort(401, _('Unauthorized to create user %s') % '')
@@ -169,7 +184,7 @@ class UserController(BaseController):
             abort(404, _('User not found'))
         except DataError:
             abort(400, _(u'Integrity Error'))
-        except CaptchaError:
+        except captcha.CaptchaError:
             error_msg = _(u'Bad Captcha. Please try again.')
             h.flash_error(error_msg)
             return self.new(data_dict)
@@ -194,9 +209,7 @@ class UserController(BaseController):
             return render('user/logout_first.html')
 
     def edit(self, id=None, data=None, errors=None, error_summary=None):
-        context = {'model': model, 'session': model.Session,
-                   'user': c.user or c.author,
-                   'save': 'save' in request.params,
+        context = {'save': 'save' in request.params,
                    'schema': self._edit_form_to_db_schema(),
                    }
         if id is None:
@@ -228,7 +241,7 @@ class UserController(BaseController):
 
         user_obj = context.get('user_obj')
 
-        if not (ckan.authz.Authorizer().is_sysadmin(unicode(c.user))
+        if not (new_authz.is_sysadmin(c.user)
                 or c.user == user_obj.name):
             abort(401, _('User %s not authorized to edit %s') %
                   (str(c.user), id))
@@ -242,16 +255,23 @@ class UserController(BaseController):
                                        data_dict)
 
         c.is_myself = True
+        c.show_email_notifications = h.asbool(
+            config.get('ckan.activity_streams_email_notifications'))
         c.form = render(self.edit_user_form, extra_vars=vars)
 
         return render('user/edit.html')
 
     def _save_edit(self, id, context):
         try:
-            data_dict = clean_dict(unflatten(
-                tuplize_dict(parse_params(request.params))))
+            data_dict = logic.clean_dict(unflatten(
+                logic.tuplize_dict(logic.parse_params(request.params))))
             context['message'] = data_dict.get('log_message', '')
             data_dict['id'] = id
+
+            # MOAN: Do I really have to do this here?
+            if 'activity_streams_email_notifications' not in data_dict:
+                data_dict['activity_streams_email_notifications'] = False
+
             user = get_action('user_update')(context, data_dict)
             h.flash_success(_('Profile updated'))
             h.redirect_to(controller='user', action='read', id=user['name'])
@@ -266,7 +286,7 @@ class UserController(BaseController):
             error_summary = e.error_summary
             return self.edit(id, data_dict, errors, error_summary)
 
-    def login(self):
+    def login(self, error=None):
         lang = session.pop('lang', None)
         if lang:
             session.save()
@@ -281,9 +301,15 @@ class UserController(BaseController):
             g.openid_enabled = False
 
         if not c.user:
+            came_from = request.params.get('came_from', '')
             c.login_handler = h.url_for(
-                self._get_repoze_handler('login_handler_path'))
-            return render('user/login.html')
+                self._get_repoze_handler('login_handler_path'),
+                came_from=came_from)
+            if error:
+                vars = {'error_summary': {'': error}}
+            else:
+                vars = {}
+            return render('user/login.html', extra_vars=vars)
         else:
             return render('user/logout_first.html')
 
@@ -291,29 +317,34 @@ class UserController(BaseController):
         # we need to set the language via a redirect
         lang = session.pop('lang', None)
         session.save()
+        came_from = request.params.get('came_from', '')
 
         # we need to set the language explicitly here or the flash
         # messages will not be translated.
-        ckan.lib.i18n.set_lang(lang)
+        i18n.set_lang(lang)
 
         if c.user:
-            context = {'model': model,
-                       'user': c.user}
-
+            context = None
             data_dict = {'id': c.user}
 
             user_dict = get_action('user_show')(context, data_dict)
 
             h.flash_success(_("%s is now logged in") %
                             user_dict['display_name'])
-            return self.me(locale=lang)
+            if came_from:
+                return h.redirect_to(str(came_from))
+            return self.me()
         else:
             err = _('Login failed. Bad username or password.')
             if g.openid_enabled:
                 err += _(' (Or if using OpenID, it hasn\'t been associated '
                          'with a user account.)')
-            h.flash_error(err)
-            h.redirect_to(locale=lang, controller='user', action='login')
+            if h.asbool(config.get('ckan.legacy_templates', 'false')):
+                h.flash_error(err)
+                h.redirect_to(locale=lang, controller='user',
+                              action='login', came_from=came_from)
+            else:
+                return self.login(error=err)
 
     def logout(self):
         # save our language in the session so we don't lose it
@@ -383,6 +414,9 @@ class UserController(BaseController):
         return render('user/request_reset.html')
 
     def perform_reset(self, id):
+        # FIXME 403 error for invalid key is a non helpful page
+        # FIXME We should reset the reset key when it is used to prevent
+        # reuse of the url
         context = {'model': model, 'session': model.Session,
                    'user': c.user,
                    'keep_sensitive_data': True}
@@ -429,16 +463,6 @@ class UserController(BaseController):
         c.user_dict = user_dict
         return render('user/perform_reset.html')
 
-    def _format_about(self, about):
-        about_formatted = ckan.misc.MarkdownFormat().to_html(about)
-        try:
-            html = genshi.HTML(about_formatted)
-        except genshi.ParseError, e:
-            log.error('Could not print "about" field Field: %r Error: %r',
-                      about, e)
-            html = _('Error: Could not parse About text')
-        return html
-
     def _get_form_password(self):
         password1 = request.params.getone('password1')
         password2 = request.params.getone('password2')
@@ -450,19 +474,148 @@ class UserController(BaseController):
                 raise ValueError(_('The passwords you entered'
                                  ' do not match.'))
             return password1
+        raise ValueError(_('You must provide a password'))
 
     def followers(self, id=None):
-        context = {'model': model, 'session': model.Session,
-                   'user': c.user or c.author, 'for_view': True}
+        context = {'for_view': True}
         data_dict = {'id': id, 'user_obj': c.userobj}
         self._setup_template_variables(context, data_dict)
         f = get_action('user_follower_list')
-        c.followers = f(context, {'id': c.user_dict['id']})
+        try:
+            c.followers = f(context, {'id': c.user_dict['id']})
+        except NotAuthorized:
+            abort(401, _('Unauthorized to view followers %s') % '')
         return render('user/followers.html')
 
-    def dashboard(self, id=None):
+    def activity(self, id, offset=0):
+        '''Render this user's public activity stream page.'''
+
         context = {'model': model, 'session': model.Session,
                    'user': c.user or c.author, 'for_view': True}
         data_dict = {'id': id, 'user_obj': c.userobj}
+        try:
+            check_access('user_show', context, data_dict)
+        except NotAuthorized:
+            abort(401, _('Not authorized to see this page'))
+
         self._setup_template_variables(context, data_dict)
+
+        c.user_activity_stream = get_action('user_activity_list_html')(
+            context, {'id': c.user_dict['id'], 'offset': offset})
+
+        return render('user/activity_stream.html')
+
+    def _get_dashboard_context(self, filter_type=None, filter_id=None,
+            q=None):
+        '''Return a dict needed by the dashboard view to determine context.'''
+
+        def display_name(followee):
+            '''Return a display name for a user, group or dataset dict.'''
+            display_name = followee.get('display_name')
+            fullname = followee.get('fullname')
+            title = followee.get('title')
+            name = followee.get('name')
+            return display_name or fullname or title or name
+
+        if (filter_type and filter_id):
+            context = {'model': model, 'session': model.Session,
+                   'user': c.user or c.author, 'for_view': True}
+            data_dict = {'id': filter_id}
+            followee = None
+
+            action_functions = {
+                'dataset': 'package_show',
+                'user': 'user_show',
+                'group': 'group_show'
+                }
+            action_function = logic.get_action(action_functions.get(filter_type))
+            # Is this a valid type?
+            if action_function is None:
+                raise abort(404, _('Follow item not found'))
+            try:
+                followee = action_function(context, data_dict)
+            except NotFound:
+                abort(404, _('{0} not found').format(filter_type))
+            except NotAuthorized:
+                abort(401, _('Unauthorized to read {0} {1}').format(
+                    filter_type, id))
+
+            if followee is not None:
+                return {
+                    'filter_type': filter_type,
+                    'q': q,
+                    'context': display_name(followee),
+                    'selected_id': followee.get('id'),
+                    'dict': followee,
+                }
+
+        return {
+            'filter_type': filter_type,
+            'q': q,
+            'context': _('Everything'),
+            'selected_id': False,
+            'dict': None,
+        }
+
+    def dashboard(self, id=None, offset=0):
+        context = {'model': model, 'session': model.Session,
+                   'user': c.user or c.author, 'for_view': True}
+        data_dict = {'id': id, 'user_obj': c.userobj, 'offset': offset}
+        self._setup_template_variables(context, data_dict)
+
+        q = request.params.get('q', u'')
+        filter_type = request.params.get('type', u'')
+        filter_id = request.params.get('name', u'')
+
+        c.followee_list = get_action('followee_list')(
+            context, {'id': c.userobj.id, 'q': q})
+        c.dashboard_activity_stream_context = self._get_dashboard_context(
+            filter_type, filter_id, q)
+        c.dashboard_activity_stream = h.dashboard_activity_stream(
+            c.userobj.id, filter_type, filter_id, offset
+        )
+
+        # Mark the user's new activities as old whenever they view their
+        # dashboard page.
+        get_action('dashboard_mark_activities_old')(context, {})
+
         return render('user/dashboard.html')
+
+    def follow(self, id):
+        '''Start following this user.'''
+        context = {'model': model,
+                   'session': model.Session,
+                   'user': c.user or c.author}
+        data_dict = {'id': id}
+        try:
+            get_action('follow_user')(context, data_dict)
+            user_dict = get_action('user_show')(context, data_dict)
+            h.flash_success(_("You are now following {0}").format(
+                user_dict['display_name']))
+        except ValidationError as e:
+            error_message = (e.extra_msg or e.message or e.error_summary
+                             or e.error_dict)
+            h.flash_error(error_message)
+        except NotAuthorized as e:
+            h.flash_error(e.extra_msg)
+        h.redirect_to(controller='user', action='read', id=id)
+
+    def unfollow(self, id):
+        '''Stop following this user.'''
+        context = {'model': model,
+                   'session': model.Session,
+                   'user': c.user or c.author}
+        data_dict = {'id': id}
+        try:
+            get_action('unfollow_user')(context, data_dict)
+            user_dict = get_action('user_show')(context, data_dict)
+            h.flash_success(_("You are no longer following {0}").format(
+                user_dict['display_name']))
+        except (NotFound, NotAuthorized) as e:
+            error_message = e.extra_msg or e.message
+            h.flash_error(error_message)
+        except ValidationError as e:
+            error_message = (e.error_summary or e.message or e.extra_msg
+                             or e.error_dict)
+            h.flash_error(error_message)
+        h.redirect_to(controller='user', action='read', id=id)
