@@ -11,6 +11,7 @@ from pylons.i18n.translation import _
 from pylons import config, g
 from ckan import model, __version__
 from ckan.lib.helpers import url_for
+import paste.deploy.converters
 
 log = logging.getLogger(__name__)
 
@@ -25,7 +26,7 @@ def add_msg_niceties(recipient_name, body, sender_name, sender_url):
 def _mail_recipient(recipient_name, recipient_email,
         sender_name, sender_url, subject,
         body, headers={}):
-    mail_from = config.get('ckan.mail_from')
+    mail_from = config.get('smtp.mail_from')
     body = add_msg_niceties(recipient_name, body, sender_name, sender_url)
     msg = MIMEText(body.encode('utf-8'), 'plain', 'utf-8')
     for k, v in headers.items(): msg[k] = v
@@ -36,17 +37,54 @@ def _mail_recipient(recipient_name, recipient_email,
     msg['To'] = Header(recipient, 'utf-8')
     msg['Date'] = Utils.formatdate(time())
     msg['X-Mailer'] = "CKAN %s" % __version__
+
+    # Send the email using Python's smtplib.
+    smtp_connection = smtplib.SMTP()
+    if 'smtp.test_server' in config:
+        # If 'smtp.test_server' is configured we assume we're running tests,
+        # and don't use the smtp.server, starttls, user, password etc. options.
+        smtp_server = config['smtp.test_server']
+        smtp_starttls = False
+        smtp_user = None
+        smtp_password = None
+    else:
+        smtp_server = config.get('smtp.server', 'localhost')
+        smtp_starttls = paste.deploy.converters.asbool(
+                config.get('smtp.starttls'))
+        smtp_user = config.get('smtp.user')
+        smtp_password = config.get('smtp.password')
+    smtp_connection.connect(smtp_server)
     try:
-        server = smtplib.SMTP(
-            config.get('test_smtp_server',
-                       config.get('smtp_server', 'localhost')))
-        #server.set_debuglevel(1)
-        server.sendmail(mail_from, [recipient_email], msg.as_string())
-        server.quit()
-    except Exception, e:
+        #smtp_connection.set_debuglevel(True)
+
+        # Identify ourselves and prompt the server for supported features.
+        smtp_connection.ehlo()
+
+        # If 'smtp.starttls' is on in CKAN config, try to put the SMTP
+        # connection into TLS mode.
+        if smtp_starttls:
+            if smtp_connection.has_extn('STARTTLS'):
+                smtp_connection.starttls()
+                # Re-identify ourselves over TLS connection.
+                smtp_connection.ehlo()
+            else:
+                raise MailerException("SMTP server does not support STARTTLS")
+
+        # If 'smtp.user' is in CKAN config, try to login to SMTP server.
+        if smtp_user:
+            assert smtp_password, ("If smtp.user is configured then "
+                    "smtp.password must be configured as well.")
+            smtp_connection.login(smtp_user, smtp_password)
+
+        smtp_connection.sendmail(mail_from, [recipient_email], msg.as_string())
+        log.info("Sent email to {0}".format(recipient_email))
+
+    except smtplib.SMTPException, e:
         msg = '%r' % e
         log.exception(msg)
         raise MailerException(msg)
+    finally:
+        smtp_connection.quit()
 
 def mail_recipient(recipient_name, recipient_email, subject,
         body, headers={}):
