@@ -3,10 +3,10 @@ import logging
 from pylons import c
 from ckan.lib import base
 from ckan.lib.navl import dictization_functions
-from ckan import authz
 from ckan import logic
 import logic.schema
 from ckan import plugins
+import ckan.new_authz
 
 log = logging.getLogger(__name__)
 
@@ -72,14 +72,21 @@ def register_package_plugins(map):
         for package_type in plugin.package_types():
             # Create a connection between the newly named type and the
             # package controller
-            map.connect('/%s/new' % package_type,
+
+            map.connect('%s_search' % package_type, '/%s' % package_type,
+                        controller='package', action='search')
+
+            map.connect('%s_new' % package_type, '/%s/new' % package_type,
                         controller='package', action='new')
             map.connect('%s_read' % package_type, '/%s/{id}' % package_type,
                         controller='package', action='read')
-            map.connect('%s_action' % package_type,
-                        '/%s/{action}/{id}' % package_type, controller='package',
-                requirements=dict(action='|'.join(['edit', 'authz', 'history' ]))
-            )
+
+            for action in ['edit', 'authz', 'history']:
+                map.connect('%s_%s' % (package_type, action),
+                        '/%s/%s/{id}' % (package_type, action),
+                        controller='package',
+                        action=action
+                )
 
             if package_type in _package_plugins:
                 raise ValueError, "An existing IDatasetForm is "\
@@ -92,8 +99,6 @@ def register_package_plugins(map):
         _default_package_plugin = DefaultDatasetForm()
 
 
-
-
 def register_group_plugins(map):
     """
     Register the various IGroupForm instances.
@@ -138,7 +143,7 @@ def register_group_plugins(map):
                         controller='group', action='read')
             map.connect('%s_action' % group_type,
                         '/%s/{action}/{id}' % group_type, controller='group',
-                requirements=dict(action='|'.join(['edit', 'authz', 'history' ]))
+                requirements=dict(action='|'.join(['edit', 'authz', 'history']))
             )
 
             if group_type in _group_plugins:
@@ -153,136 +158,40 @@ def register_group_plugins(map):
 
 
 class DefaultDatasetForm(object):
-    """
-    Provides a default implementation of the pluggable package
-    controller behaviour.
+    '''The default implementation of IDatasetForm.
 
-    This class has 2 purposes:
+    See ckan.plugins.interfaces.IDatasetForm.
 
-     - it provides a base class for IDatasetForm implementations to use
-       if only a subset of the 5 method hooks need to be customised.
+    This class has two purposes:
 
-     - it provides the fallback behaviour if no plugin is setup to
-       provide the fallback behaviour.
+    1. It provides a base class for IDatasetForm implementations to inherit
+       from.
+
+    2. It is used as the default fallback plugin, if no IDatasetForm plugin
+       registers itself as the fallback.
 
     Note - this isn't a plugin implementation. This is deliberate, as we
            don't want this being registered.
-    """
-    def new_template(self):
-        """
-        Returns a string representing the location of the template to be
-        rendered for the new page
-        """
-        return 'package/new.html'
 
-    def comments_template(self):
-        """
-        Returns a string representing the location of the template to be
-        rendered for the comments page
-        """
-        return 'package/comments.html'
+    '''
+    def create_package_schema(self):
+        return ckan.logic.schema.default_create_package_schema()
 
-    def search_template(self):
-        """
-        Returns a string representing the location of the template to be
-        rendered for the search page (if present)
-        """
-        return 'package/search.html'
+    def update_package_schema(self):
+        return ckan.logic.schema.default_update_package_schema()
 
-    def read_template(self):
-        """
-        Returns a string representing the location of the template to be
-        rendered for the read page
-        """
-        return 'package/read.html'
-
-    def history_template(self):
-        """
-        Returns a string representing the location of the template to be
-        rendered for the history page
-        """
-        return 'package/history.html'
-
-
-    def package_form(self):
-        return 'package/new_package_form.html'
-
-    def form_to_db_schema_options(self, options):
-        ''' This allows us to select different schemas for different
-        purpose eg via the web interface or via the api or creation vs
-        updating. It is optional and if not available form_to_db_schema
-        should be used.
-        If a context is provided, and it contains a schema, it will be
-        returned.
-        '''
-        schema = options.get('context',{}).get('schema',None)
-        if schema:
-            return schema
-
-        if options.get('api'):
-            if options.get('type') == 'create':
-                return self.form_to_db_schema_api_create()
-            else:
-                assert options.get('type') == 'update'
-                return self.form_to_db_schema_api_update()
-        else:
-            return self.form_to_db_schema()
-
-    def form_to_db_schema(self):
-        return logic.schema.form_to_db_package_schema()
-
-    def form_to_db_schema_api_create(self):
-        return logic.schema.default_create_package_schema()
-
-    def form_to_db_schema_api_update(self):
-        return logic.schema.default_update_package_schema()
-
-    def db_to_form_schema(self):
-        '''This is an interface to manipulate data from the database
-        into a format suitable for the form (optional)'''
-
-    def db_to_form_schema_options(self, options):
-        '''This allows the selectino of different schemas for different
-        purposes.  It is optional and if not available, ``db_to_form_schema``
-        should be used.
-        If a context is provided, and it contains a schema, it will be
-        returned.
-        '''
-        schema = options.get('context',{}).get('schema',None)
-        if schema:
-            return schema
-        return self.db_to_form_schema()
-
-    def check_data_dict(self, data_dict, schema=None):
-        '''Check if the return data is correct, mostly for checking out
-        if spammers are submitting only part of the form'''
-
-        # Resources might not exist yet (eg. Add Dataset)
-        surplus_keys_schema = ['__extras', '__junk', 'state', 'groups',
-                               'extras_validation', 'save', 'return_to',
-                               'resources', 'type']
-
-        if not schema:
-            schema = self.form_to_db_schema()
-        schema_keys = schema.keys()
-        keys_in_schema = set(schema_keys) - set(surplus_keys_schema)
-
-        missing_keys = keys_in_schema - set(data_dict.keys())
-        if missing_keys:
-            log.info('incorrect form fields posted, missing %s' % missing_keys)
-            raise dictization_functions.DataError(data_dict)
+    def show_package_schema(self):
+        return ckan.logic.schema.default_show_package_schema()
 
     def setup_template_variables(self, context, data_dict):
-        from pylons import config
-
         authz_fn = logic.get_action('group_list_authz')
         c.groups_authz = authz_fn(context, data_dict)
-        data_dict.update({'available_only':True})
+        data_dict.update({'available_only': True})
 
         c.groups_available = authz_fn(context, data_dict)
 
         c.licences = [('', '')] + base.model.Package.get_license_options()
-        c.is_sysadmin = authz.Authorizer().is_sysadmin(c.user)
+        c.is_sysadmin = ckan.new_authz.is_sysadmin(c.user)
 
         if c.pkg:
             c.related_count = c.pkg.related_count
@@ -299,6 +208,26 @@ class DefaultDatasetForm(object):
             except logic.NotAuthorized:
                 c.auth_for_change_state = False
 
+    def new_template(self):
+        return 'package/new.html'
+
+    def read_template(self):
+        return 'package/read.html'
+
+    def edit_template(self):
+        return 'package/edit.html'
+
+    def comments_template(self):
+        return 'package/comments.html'
+
+    def search_template(self):
+        return 'package/search.html'
+
+    def history_template(self):
+        return 'package/history.html'
+
+    def package_form(self):
+        return 'package/new_package_form.html'
 
 
 class DefaultGroupForm(object):
@@ -338,6 +267,13 @@ class DefaultGroupForm(object):
         """
         return 'group/read.html'
 
+    def about_template(self):
+        """
+        Returns a string representing the location of the template to be
+        rendered for the about page
+        """
+        return 'group/about.html'
+
     def history_template(self):
         """
         Returns a string representing the location of the template to be
@@ -352,6 +288,27 @@ class DefaultGroupForm(object):
         """
         return 'group/edit.html'
 
+    def activity_template(self):
+        """
+        Returns a string representing the location of the template to be
+        rendered for the activity stream page
+        """
+        return 'group/activity_stream.html'
+
+    def admins_template(self):
+        """
+        Returns a string representing the location of the template to be
+        rendered for the admins page
+        """
+        return 'group/admins.html'
+
+    def about_template(self):
+        '''Return the path to the template for the group's 'about' page.
+
+        :rtype: string
+
+        '''
+        return 'group/about.html'
 
     def group_form(self):
         return 'group/new_group_form.html'
@@ -364,7 +321,7 @@ class DefaultGroupForm(object):
         If a context is provided, and it contains a schema, it will be
         returned.
         '''
-        schema = options.get('context',{}).get('schema',None)
+        schema = options.get('context', {}).get('schema', None)
         if schema:
             return schema
 
@@ -396,7 +353,7 @@ class DefaultGroupForm(object):
         If a context is provided, and it contains a schema, it will be
         returned.
         '''
-        schema = options.get('context',{}).get('schema',None)
+        schema = options.get('context', {}).get('schema', None)
         if schema:
             return schema
         return self.db_to_form_schema()
@@ -424,7 +381,7 @@ class DefaultGroupForm(object):
         pass
 
     def setup_template_variables(self, context, data_dict):
-        c.is_sysadmin = authz.Authorizer().is_sysadmin(c.user)
+        c.is_sysadmin = ckan.new_authz.is_sysadmin(c.user)
 
         ## This is messy as auths take domain object not data_dict
         context_group = context.get('group', None)
