@@ -3,10 +3,12 @@ import string
 import logging
 import collections
 import json
+from dateutil.parser import parse
 
 import re
 
 from pylons import config
+from paste.deploy.converters import asbool
 
 from common import SearchIndexError, make_connection
 from ckan.model import PackageRelationship
@@ -113,7 +115,7 @@ class PackageSearchIndex(SearchIndex):
         # include the extras in the main namespace
         extras = pkg_dict.get('extras', [])
         for extra in extras:
-            key, value = extra['key'], json.loads(extra['value'])
+            key, value = extra['key'], extra['value']
             if isinstance(value, (tuple, list)):
                 value = " ".join(map(unicode, value))
             key = ''.join([c for c in key if c in KEY_CHARS])
@@ -145,16 +147,21 @@ class PackageSearchIndex(SearchIndex):
         # add groups
         groups = pkg_dict.pop('groups', [])
 
-        # Capacity is different to the default only if using organizations
-        # where the dataset is only in one group. We will add the capacity
-        # from the single group that it is a part of if we have a group
-        if len(groups):
-            pkg_dict['capacity'] = groups[0].get('capacity', 'public')
+        # we use the capacity to make things private in the search index
+        if pkg_dict['private']:
+            pkg_dict['capacity'] = 'private'
         else:
             pkg_dict['capacity'] = 'public'
 
         pkg_dict['groups'] = [group['name'] for group in groups]
 
+        # if there is an owner_org we want to add this to groups for index
+        # purposes
+        if pkg_dict.get('organization'):
+           pkg_dict['organization'] = pkg_dict['organization']['name']
+        else:
+           pkg_dict['organization'] = None
+
         # tracking
         tracking_summary = pkg_dict.pop('tracking_summary', None)
         if tracking_summary:
@@ -184,7 +191,24 @@ class PackageSearchIndex(SearchIndex):
 
         pkg_dict[TYPE_FIELD] = PACKAGE_TYPE
 
-        pkg_dict = dict([(k.encode('ascii', 'ignore'), v) for (k, v) in pkg_dict.items()])
+        # Save dataset type
+        pkg_dict['dataset_type'] = pkg_dict['type']
+
+        # clean the dict fixing keys and dates
+        # FIXME where are we getting these dirty keys from?  can we not just
+        # fix them in the correct place or is this something that always will
+        # be needed?  For my data not changing the keys seems to not cause a
+        # problem.
+        new_dict = {}
+        for key, value in pkg_dict.items():
+            key = key.encode('ascii', 'ignore')
+            if key.endswith('_date'):
+                try:
+                    value = parse(value).isoformat() + 'Z'
+                except ValueError:
+                    continue
+            new_dict[key] = value
+        pkg_dict = new_dict
 
         for k in ('title', 'notes', 'title_string'):
             if k in pkg_dict and pkg_dict[k]:
@@ -223,6 +247,8 @@ class PackageSearchIndex(SearchIndex):
         try:
             conn = make_connection()
             commit = not defer_commit
+            if not asbool(config.get('ckan.search.solr_commit', 'true')):
+                commit = False
             conn.add_many([pkg_dict], _commit=commit)
         except Exception, e:
             log.exception(e)
@@ -236,7 +262,7 @@ class PackageSearchIndex(SearchIndex):
     def commit(self):
         try:
             conn = make_connection()
-            conn.commit(wait_flush=False, wait_searcher=False)
+            conn.commit(wait_searcher=False)
         except Exception, e:
             log.exception(e)
             raise SearchIndexError(e)
@@ -251,7 +277,8 @@ class PackageSearchIndex(SearchIndex):
                                                        config.get('ckan.site_id'))
         try:
             conn.delete_query(query)
-            conn.commit()
+            if asbool(config.get('ckan.search.solr_commit', 'true')):
+                conn.commit()
         except Exception, e:
             log.exception(e)
             raise SearchIndexError(e)
