@@ -1146,26 +1146,22 @@ def package_search(context, data_dict):
 
     This action accepts a *subset* of solr's search query parameters:
 
+
     :param q: the solr query.  Optional.  Default: `"*:*"`
     :type q: string
     :param fq: any filter queries to apply.  Note: `+site_id:{ckan_site_id}`
         is added to this string prior to the query being executed.
     :type fq: string
-    :param rows: the number of matching rows to return.
-    :type rows: int
     :param sort: sorting of the search results.  Optional.  Default:
         'relevance asc, metadata_modified desc'.  As per the solr
         documentation, this is a comma-separated string of field names and
         sort-orderings.
     :type sort: string
+    :param rows: the number of matching rows to return.
+    :type rows: int
     :param start: the offset in the complete result for where the set of
         returned datasets should begin.
     :type start: int
-    :param qf: the dismax query fields to search within, including boosts.  See
-        the `Solr Dismax Documentation
-        <http://wiki.apache.org/solr/DisMaxQParserPlugin#qf_.28Query_Fields.29>`_
-        for further details.
-    :type qf: string
     :param facet: whether to enable faceted results.  Default: "true".
     :type facet: string
     :param facet.mincount: the minimum counts for facet fields should be
@@ -1178,6 +1174,18 @@ def package_search(context, data_dict):
         then the returned facet information is empty.
     :type facet.field: list of strings
 
+
+    The following advanced Solr parameters are supported as well. Note that
+    some of these are only available on particular Solr versions. See Solr's
+    `dismax`_ and `edismax`_ documentation for further details on them:
+
+    ``qf``, ``wt``, ``bf``, ``boost``, ``tie``, ``defType``, ``mm``
+
+
+    .. _dismax: http://wiki.apache.org/solr/DisMaxQParserPlugin
+    .. _edismax: http://wiki.apache.org/solr/ExtendedDisMax
+
+
     **Results:**
 
     The result of this action is a dict with the following keys:
@@ -1229,6 +1237,12 @@ def package_search(context, data_dict):
 
     _check_access('package_search', context, data_dict)
 
+    # Move ext_ params to extras and remove them from the root of the search
+    # params, so they don't cause and error
+    data_dict['extras'] = data_dict.get('extras', {})
+    for key in [key for key in data_dict.keys() if key.startswith('ext_')]:
+        data_dict['extras'][key] = data_dict.pop(key)
+
     # check if some extension needs to modify the search params
     for item in plugins.PluginImplementations(plugins.IPackageController):
         data_dict = item.before_search(data_dict)
@@ -1255,9 +1269,15 @@ def package_search(context, data_dict):
                             if not 'capacity:' in p)
             data_dict['fq'] = fq + ' capacity:"public"'
 
+        # Pop these ones as Solr does not need them
+        extras = data_dict.pop('extras', None)
+
         query = search.query_for(model.Package)
         query.run(data_dict)
 
+        # Add them back so extensions can use them on after_search
+        data_dict['extras'] = extras
+
         for package in query.results:
             # get the package object
             package, package_dict = package['id'], package.get('data_dict')
