@@ -168,7 +168,6 @@ def resource_update(context, data_dict):
     model = context['model']
     user = context['user']
     id = _get_or_bust(data_dict, "id")
-    schema = context.get('schema') or ckan.logic.schema.default_update_resource_schema()
 
     resource = model.Resource.get(id)
     context["resource"] = resource
@@ -179,6 +178,13 @@ def resource_update(context, data_dict):
 
     _check_access('resource_update', context, data_dict)
 
+    if 'schema' in context:
+        schema = context['schema']
+    else:
+        package_plugin = lib_plugins.lookup_package_plugin(
+            resource.resource_group.package.type)
+        schema = package_plugin.update_package_schema()['resources']
+
     data, errors = _validate(data_dict, schema, context)
     if errors:
         model.Session.rollback()
