@@ -1,20 +1,30 @@
 import ckan.logic as logic
+import ckan.new_authz as new_authz
 from ckan.logic.auth import (get_package_object, get_resource_object,
-                            get_group_object, get_authorization_group_object,
-                            get_user_object, get_resource_object, get_related_object)
+                            get_group_object, get_user_object,
+                            get_resource_object, get_related_object)
 from ckan.logic.auth.create import _check_group_auth, package_relationship_create
-from ckan.authz import Authorizer
 from ckan.lib.base import _
+import ckan.new_authz
 
 def make_latest_pending_package_active(context, data_dict):
     return package_update(context, data_dict)
 
 def package_update(context, data_dict):
-    model = context['model']
     user = context.get('user')
     package = get_package_object(context, data_dict)
 
-    check1 = logic.check_access_old(package, model.Action.EDIT, context)
+    if package.owner_org:
+        # if there is an owner org then we must have update_dataset
+        # premission for that organization
+        check1 = new_authz.has_user_permission_for_group_or_org(package.owner_org, user, 'update_dataset')
+    else:
+        # If dataset is not owned then we can edit if config permissions allow
+        if new_authz.auth_is_registered_user():
+            check1 = new_authz.check_config_permission(
+                'create_dataset_if_not_in_organization')
+        else:
+            check1 = new_authz.check_config_permission('anon_create_dataset')
     if not check1:
         return {'success': False, 'msg': _('User %s not authorized to edit package %s') % (str(user), package.id)}
     else:
@@ -42,7 +52,7 @@ def resource_update(context, data_dict):
     authorized = package_update(context, pkg_dict).get('success')
 
     if not authorized:
-        return {'success': False, 'msg': _('User %s not authorized to read edit %s') % (str(user), resource.id)}
+        return {'success': False, 'msg': _('User %s not authorized to edit resource %s') % (str(user), resource.id)}
     else:
         return {'success': True}
 
@@ -50,35 +60,33 @@ def package_relationship_update(context, data_dict):
     return package_relationship_create(context, data_dict)
 
 def package_change_state(context, data_dict):
-    model = context['model']
     user = context['user']
     package = get_package_object(context, data_dict)
 
-    authorized = logic.check_access_old(package, model.Action.CHANGE_STATE, context)
+    # use the logic for package_update
+    authorized = new_authz.is_authorized_boolean('package_update', context, data_dict)
     if not authorized:
         return {'success': False, 'msg': _('User %s not authorized to change state of package %s') % (str(user),package.id)}
     else:
         return {'success': True}
 
-def package_edit_permissions(context, data_dict):
-    model = context['model']
+def group_update(context, data_dict):
+    group = get_group_object(context, data_dict)
     user = context['user']
-    package = get_package_object(context, data_dict)
-
-    authorized = logic.check_access_old(package, model.Action.EDIT_PERMISSIONS, context)
+    authorized = new_authz.has_user_permission_for_group_or_org(
+        group.id, user, 'update')
     if not authorized:
-        return {'success': False, 'msg': _('User %s not authorized to edit permissions of package %s') % (str(user),package.id)}
+        return {'success': False, 'msg': _('User %s not authorized to edit group %s') % (str(user),group.id)}
     else:
         return {'success': True}
 
-def group_update(context, data_dict):
-    model = context['model']
-    user = context['user']
+def organization_update(context, data_dict):
     group = get_group_object(context, data_dict)
-
-    authorized = logic.check_access_old(group, model.Action.EDIT, context)
+    user = context['user']
+    authorized = new_authz.has_user_permission_for_group_or_org(
+        group.id, user, 'update')
     if not authorized:
-        return {'success': False, 'msg': _('User %s not authorized to edit group %s') % (str(user),group.id)}
+        return {'success': False, 'msg': _('User %s not authorized to edit organization %s') % (user, group.id)}
     else:
         return {'success': True}
 
@@ -94,10 +102,7 @@ def related_update(context, data_dict):
         return {'success': False, 'msg': _('Only the owner can update a related item')}
 
     # Only sysadmins can change the featured field.
-    if ('featured' in data_dict and
-        data_dict['featured'] != related.featured and
-        not Authorizer().is_sysadmin(unicode(user))):
-
+    if ('featured' in data_dict and data_dict['featured'] != related.featured):
         return {'success': False,
                 'msg': _('You must be a sysadmin to change a related item\'s '
                          'featured field.')}
@@ -106,98 +111,69 @@ def related_update(context, data_dict):
 
 
 def group_change_state(context, data_dict):
-    model = context['model']
     user = context['user']
     group = get_group_object(context, data_dict)
 
-    authorized = logic.check_access_old(group, model.Action.CHANGE_STATE, context)
+    # use logic for group_update
+    authorized = new_authz.is_authorized_boolean('group_update', context, data_dict)
     if not authorized:
         return {'success': False, 'msg': _('User %s not authorized to change state of group %s') % (str(user),group.id)}
     else:
         return {'success': True}
 
 def group_edit_permissions(context, data_dict):
-    model = context['model']
     user = context['user']
     group = get_group_object(context, data_dict)
 
-    authorized = logic.check_access_old(group, model.Action.EDIT_PERMISSIONS, context)
-    if not authorized:
+    if not new_authz.has_user_permission_for_group_or_org(group.id, user, 'update'):
         return {'success': False, 'msg': _('User %s not authorized to edit permissions of group %s') % (str(user),group.id)}
     else:
         return {'success': True}
 
-def authorization_group_update(context, data_dict):
-    model = context['model']
-    user = context['user']
-    authorization_group = get_authorization_group_object(context, data_dict)
 
-    authorized = logic.check_access_old(authorization_group, model.Action.EDIT, context)
-    if not authorized:
-        return {'success': False, 'msg': _('User %s not authorized to edit permissions of authorization group %s') % (str(user),authorization_group.id)}
-    else:
-        return {'success': True}
-
-def authorization_group_edit_permissions(context, data_dict):
-    model = context['model']
-    user = context['user']
-    authorization_group = get_authorization_group_object(context, data_dict)
-
-    authorized = logic.check_access_old(authorization_group, model.Action.EDIT_PERMISSIONS, context)
-    if not authorized:
-        return {'success': False, 'msg': _('User %s not authorized to edit permissions of authorization group %s') % (str(user),authorization_group.id)}
-    else:
-        return {'success': True}
 
 def user_update(context, data_dict):
     user = context['user']
     user_obj = get_user_object(context, data_dict)
 
-    if not (Authorizer().is_sysadmin(unicode(user)) or user == user_obj.name) and \
+    if not (user == user_obj.name) and \
        not ('reset_key' in data_dict and data_dict['reset_key'] == user_obj.reset_key):
         return {'success': False, 'msg': _('User %s not authorized to edit user %s') % (str(user), user_obj.id)}
 
     return {'success': True}
 
 def revision_change_state(context, data_dict):
-    model = context['model']
+    # FIXME currently only sysadmins can change state
     user = context['user']
 
-    authorized = Authorizer().is_authorized(user, model.Action.CHANGE_STATE, model.Revision)
-    if not authorized:
-        return {'success': False, 'msg': _('User %s not authorized to change state of revision' ) % str(user)}
-    else:
-        return {'success': True}
+    return {'success': False, 'msg': _('User %s not authorized to change state of revision' ) % user}
 
 def task_status_update(context, data_dict):
-    model = context['model']
+    # sysadmins only
     user = context['user']
-
-    if 'ignore_auth' in context and context['ignore_auth']:
-        return {'success': True}
-
-    authorized =  Authorizer().is_sysadmin(unicode(user))
-    if not authorized:
-        return {'success': False, 'msg': _('User %s not authorized to update task_status table') % str(user)}
-    else:
-        return {'success': True}
+    return {'success': False, 'msg': _('User %s not authorized to update task_status table') % user}
 
 def vocabulary_update(context, data_dict):
-    user = context['user']
-    return {'success': Authorizer.is_sysadmin(user)}
+    # sysadmins only
+    return {'success': False}
 
 def term_translation_update(context, data_dict):
-
+    # sysadmins only
     user = context['user']
+    return {'success': False, 'msg': _('User %s not authorized to update term_translation table') % user}
 
-    if 'ignore_auth' in context and context['ignore_auth']:
-        return {'success': True}
 
-    authorized =  Authorizer().is_sysadmin(unicode(user))
-    if not authorized:
-        return {'success': False, 'msg': _('User %s not authorized to update term_translation table') % str(user)}
-    else:
-        return {'success': True}
+def dashboard_mark_activities_old(context, data_dict):
+    # FIXME: This should go through check_access() not call is_authorized()
+    # directly, but wait until 2939-orgs is merged before fixing this.
+    return ckan.new_authz.is_authorized('dashboard_activity_list',
+            context, data_dict)
+
+
+def send_email_notifications(context, data_dict):
+    # Only sysadmins are authorized to send email notifications.
+    return {'success': False}
+
 
 ## Modifications for rest api
 
@@ -217,3 +193,6 @@ def group_update_rest(context, data_dict):
 
     return group_update(context, data_dict)
 
+def package_owner_org_update(context, data_dict):
+    # sysadmins only
+    return {'success': False}
