@@ -1,9 +1,11 @@
 import vdm.sqlalchemy
+from sqlalchemy import orm, types, Column, Table, ForeignKey
 
-from meta import *
-from core import *
-from package import *
-from types import make_uuid
+import meta
+import core
+import package as _package
+import types as _types
+import domain_object
 
 # i18n only works when this is run as part of pylons,
 # which isn't the case for paster commands.
@@ -14,21 +16,23 @@ except:
     def _(txt):
         return txt
 
+__all__ = ['PackageRelationship', 'package_relationship_table',
+           'package_relationship_revision_table']
 
-package_relationship_table = Table('package_relationship', metadata,
-     Column('id', UnicodeText, primary_key=True, default=make_uuid),
-     Column('subject_package_id', UnicodeText, ForeignKey('package.id')),
-     Column('object_package_id', UnicodeText, ForeignKey('package.id')),
-     Column('type', UnicodeText),
-     Column('comment', UnicodeText),
+package_relationship_table = Table('package_relationship', meta.metadata,
+     Column('id', types.UnicodeText, primary_key=True, default=_types.make_uuid),
+     Column('subject_package_id', types.UnicodeText, ForeignKey('package.id')),
+     Column('object_package_id', types.UnicodeText, ForeignKey('package.id')),
+     Column('type', types.UnicodeText),
+     Column('comment', types.UnicodeText),
      )
 
 vdm.sqlalchemy.make_table_stateful(package_relationship_table)
-package_relationship_revision_table = make_revisioned_table(package_relationship_table)
+package_relationship_revision_table = core.make_revisioned_table(package_relationship_table)
 
 class PackageRelationship(vdm.sqlalchemy.RevisionedObjectMixin,
                           vdm.sqlalchemy.StatefulObjectMixin,
-                          DomainObject):
+                          domain_object.DomainObject):
     '''The rule with PackageRelationships is that they are stored in the model
     always as the "forward" relationship - i.e. "child_of" but never
     as "parent_of". However, the model functions provide the relationships
@@ -55,8 +59,7 @@ class PackageRelationship(vdm.sqlalchemy.RevisionedObjectMixin,
             {'sibling':_('has sibling %s')}
 
     def __str__(self):
-        from ckan import model
-        return '<%sPackageRelationship %s %s %s>' % ("*" if self.active != model.State.ACTIVE else "",
+        return '<%sPackageRelationship %s %s %s>' % ("*" if self.active != core.State.ACTIVE else "",
                                                      self.subject.name, self.type, self.object.name)
 
     def __repr__(self):
@@ -88,7 +91,7 @@ class PackageRelationship(vdm.sqlalchemy.RevisionedObjectMixin,
         of the given package with the object package object.
         e.g. rel.as_tuple(warandpeace) gives (u'depends_on', annakarenina)
         meaning warandpeace depends_on annakarenina.'''
-        assert isinstance(package, Package), package
+        assert isinstance(package, _package.Package), package
         if self.subject == package:
             type_str = self.type
             other_package = self.object
@@ -96,17 +99,18 @@ class PackageRelationship(vdm.sqlalchemy.RevisionedObjectMixin,
             type_str = self.forward_to_reverse_type(self.type)
             other_package = self.subject
         else:
-            raise InputError('Package %s is not in this relationship: %s' % \
+            # FIXME do we want a more specific error
+            raise Exception('Package %s is not in this relationship: %s' % \
                              (package, self))
         return (type_str, other_package)
         
     @classmethod
     def by_subject(cls, package):
-        return Session.query(cls).filter(cls.subject_package_id==package.id)
+        return meta.Session.query(cls).filter(cls.subject_package_id==package.id)
 
     @classmethod
     def by_object(cls, package):
-        return Session.query(cls).filter(cls.object_package_id==package.id)
+        return meta.Session.query(cls).filter(cls.object_package_id==package.id)
     
     @classmethod
     def get_forward_types(cls):
@@ -157,16 +161,16 @@ class PackageRelationship(vdm.sqlalchemy.RevisionedObjectMixin,
                     return cls.types_printable[i][j]
         raise TypeError, type_
 
-mapper(PackageRelationship, package_relationship_table, properties={
-    'subject':relation(Package, primaryjoin=\
-           package_relationship_table.c.subject_package_id==Package.id,
+meta.mapper(PackageRelationship, package_relationship_table, properties={
+    'subject':orm.relation(_package.Package, primaryjoin=\
+           package_relationship_table.c.subject_package_id==_package.Package.id,
            backref='relationships_as_subject'),
-    'object':relation(Package, primaryjoin=package_relationship_table.c.object_package_id==Package.id,
+    'object':orm.relation(_package.Package, primaryjoin=package_relationship_table.c.object_package_id==_package.Package.id,
            backref='relationships_as_object'),
     },
     extension = [vdm.sqlalchemy.Revisioner(package_relationship_revision_table)]
     )
 
-vdm.sqlalchemy.modify_base_object_mapper(PackageRelationship, Revision, State)
+vdm.sqlalchemy.modify_base_object_mapper(PackageRelationship, core.Revision, core.State)
 PackageRelationshipRevision = vdm.sqlalchemy.create_object_version(
-    mapper, PackageRelationship, package_relationship_revision_table)
+    meta.mapper, PackageRelationship, package_relationship_revision_table)
