@@ -14,11 +14,11 @@ from ckan.lib.base import g
 class TestMailer(SmtpServerHarness, PylonsTestCase):
     @classmethod
     def setup_class(cls):
-        smtp_server = config.get('test_smtp_server')
+        smtp_server = config.get('smtp.test_server')
         if smtp_server:
             host, port = smtp_server.split(':')
             port = int(port) + int(str(hashlib.md5(cls.__name__).hexdigest())[0], 16)
-            config['test_smtp_server'] = '%s:%s' % (host, port)
+            config['smtp.test_server'] = '%s:%s' % (host, port)
         CreateTestData.create_user(name='bob', email='bob@bob.net')
         CreateTestData.create_user(name='mary') #NB No email addr provided
         SmtpServerHarness.setup_class()
@@ -56,7 +56,7 @@ class TestMailer(SmtpServerHarness, PylonsTestCase):
         msgs = self.get_smtp_messages()
         assert_equal(len(msgs), 1)
         msg = msgs[0]
-        assert_equal(msg[1], config['ckan.mail_from'])
+        assert_equal(msg[1], config['smtp.mail_from'])
         assert_equal(msg[2], [test_email['recipient_email']])
         assert test_email['headers'].keys()[0] in msg[3], msg[3]
         assert test_email['headers'].values()[0] in msg[3], msg[3]
@@ -81,7 +81,7 @@ class TestMailer(SmtpServerHarness, PylonsTestCase):
         msgs = self.get_smtp_messages()
         assert_equal(len(msgs), 1)
         msg = msgs[0]
-        assert_equal(msg[1], config['ckan.mail_from'])
+        assert_equal(msg[1], config['smtp.mail_from'])
         assert_equal(msg[2], [model.User.by_name(u'bob').email])
         assert test_email['headers'].keys()[0] in msg[3], msg[3]
         assert test_email['headers'].values()[0] in msg[3], msg[3]
@@ -107,7 +107,7 @@ class TestMailer(SmtpServerHarness, PylonsTestCase):
         msgs = self.get_smtp_messages()
         assert_equal(len(msgs), 1)
         msg = msgs[0]
-        assert_equal(msg[1], config['ckan.mail_from'])
+        assert_equal(msg[1], config['smtp.mail_from'])
         assert_equal(msg[2], [model.User.by_name(u'bob').email])
         assert 'Reset' in msg[3], msg[3]
         test_msg = get_reset_link_body(model.User.by_name(u'bob'))
