@@ -35,7 +35,7 @@ class PylonsTestCase(object):
         cls.context_obj=AttribSafeContextObj()
         cls.registry.register(pylons.c, cls.context_obj)
 
-        cls.app_globals_obj = app_globals.Globals()
+        cls.app_globals_obj = app_globals.app_globals
         cls.registry.register(pylons.g, cls.app_globals_obj)
 
         cls.request_obj=Request(dict(HTTP_HOST="nohost", REQUEST_METHOD="GET")) 
