@@ -1,4 +1,5 @@
 import json
+import nose
 
 import sqlalchemy.orm as orm
 
@@ -14,11 +15,13 @@ from ckanext.datastore.tests.helpers import rebuild_all_dbs
 class TestDatastoreCreate(tests.WsgiAppCase):
     sysadmin_user = None
     normal_user = None
-    p.load('datastore')
 
     @classmethod
     def setup_class(cls):
+        if not tests.is_datastore_supported():
+            raise nose.SkipTest("Datastore not supported")
         p.load('datastore')
+        cls._configure_iconfigurable_plugins()
         ctd.CreateTestData.create()
         cls.sysadmin_user = model.User.get('testsysadmin')
         cls.normal_user = model.User.get('annafan')
@@ -32,6 +35,15 @@ class TestDatastoreCreate(tests.WsgiAppCase):
     @classmethod
     def teardown_class(cls):
         rebuild_all_dbs(cls.Session)
+        p.unload('datastore')
+
+    @classmethod
+    def _configure_iconfigurable_plugins(cls):
+        import pylons.config as config
+        from ckan.plugins import PluginImplementations
+        from ckan.plugins.interfaces import IConfigurable
+        for plugin in PluginImplementations(IConfigurable):
+            plugin.configure(config)
 
     def test_create_requires_auth(self):
         resource = model.Package.get('annakarenina').resources[0]
@@ -98,7 +110,7 @@ class TestDatastoreCreate(tests.WsgiAppCase):
         resource = model.Package.get('annakarenina').resources[0]
         data = {
             'resource_id': resource.id,
-            'fields': [{'id': '_book', 'type': 'text'},
+            'fields': [{'id': 'book', 'type': 'text'},
                        {'id': '_author', 'type': 'text'}]
         }
         postparams = '%s=1' % json.dumps(data)
@@ -110,7 +122,7 @@ class TestDatastoreCreate(tests.WsgiAppCase):
 
         data = {
             'resource_id': resource.id,
-            'fields': [{'id': '"book"', 'type': 'text'},
+            'fields': [{'id': 'book', 'type': 'text'},
                        {'id': '"author', 'type': 'text'}]
         }
         postparams = '%s=1' % json.dumps(data)
@@ -119,6 +131,17 @@ class TestDatastoreCreate(tests.WsgiAppCase):
         res_dict = json.loads(res.body)
         assert res_dict['success'] is False
 
+        data = {
+            'resource_id': resource.id,
+            'fields': [{'id': 'book', 'type': 'text'},
+                       {'id': '', 'type': 'text'}]
+        }
+        postparams = '%s=1' % json.dumps(data)
+        res = self.app.post('/api/action/datastore_create', params=postparams,
+                            extra_environ=auth, status=409)
+        res_dict = json.loads(res.body)
+        assert res_dict['success'] is False
+
     def test_create_invalid_record_field(self):
         resource = model.Package.get('annakarenina').resources[0]
         data = {
@@ -453,6 +476,20 @@ class TestDatastoreCreate(tests.WsgiAppCase):
 
         assert res_dict['success'] is True, res_dict
 
+        #######  insert with paramter id rather than resource_id which is a shortcut
+        data8 = {
+            'id': resource.id,
+            'records': [{'boo%k': 'warandpeace'}]
+        }
+
+        postparams = '%s=1' % json.dumps(data8)
+        auth = {'Authorization': str(self.sysadmin_user.apikey)}
+        res = self.app.post('/api/action/datastore_create', params=postparams,
+                            extra_environ=auth, expect_errors=True)
+        res_dict = json.loads(res.body)
+
+        assert res_dict['success'] is True, res_dict
+
     def test_guess_types(self):
         resource = model.Package.get('annakarenina').resources[1]
 
@@ -560,4 +597,5 @@ class TestDatastoreCreate(tests.WsgiAppCase):
                             extra_environ=auth, status=409)
         res_dict = json.loads(res.body)
 
-        assert res_dict['success'] is False
\ No newline at end of file
+        assert res_dict['success'] is False
+
